==> aliyun-java-sdk-ecs-4.24.42-sources.jar: com/aliyuncs/ecs/model/v20140526/DescribeDiagnosticMetricSetsRequest.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.aliyuncs.ecs.model.v20140526;

import com.aliyuncs.RpcAcsRequest;
import java.util.List;
import com.aliyuncs.http.MethodType;
import com.aliyuncs.ecs.Endpoint;

/**
 * @author auto create
 * @version 
 */
public class DescribeDiagnosticMetricSetsRequest extends RpcAcsRequest<DescribeDiagnosticMetricSetsResponse> {
	   

	private List<String> metricSetIdss;

	private String type;

	private String nextToken;

	private String resourceType;

	private Integer maxResults;
	public DescribeDiagnosticMetricSetsRequest() {
		super("Ecs", "2014-05-26", "DescribeDiagnosticMetricSets");
		setMethod(MethodType.POST);
		try {
			com.aliyuncs.AcsRequest.class.getDeclaredField("productEndpointMap").set(this, Endpoint.endpointMap);
			com.aliyuncs.AcsRequest.class.getDeclaredField("productEndpointRegional").set(this, Endpoint.endpointRegionalType);
		} catch (Exception e) {}
	}

	public List<String> getMetricSetIdss() {
		return this.metricSetIdss;
	}

	public void setMetricSetIdss(List<String> metricSetIdss) {
		this.metricSetIdss = metricSetIdss;	
		if (metricSetIdss != null) {
			for (int i = 0; i < metricSetIdss.size(); i++) {
				putQueryParameter("MetricSetIds." + (i + 1) , metricSetIdss.get(i));
			}
		}	
	}

	public String getType() {
		return this.type;
	}

	public void setType(String type) {
		this.type = type;
		if(type != null){
			putQueryParameter("Type", type);
		}
	}

	public String getNextToken() {
		return this.nextToken;
	}

	public void setNextToken(String nextToken) {
		this.nextToken = nextToken;
		if(nextToken != null){
			putQueryParameter("NextToken", nextToken);
		}
	}

	public String getResourceType() {
		return this.resourceType;
	}

	public void setResourceType(String resourceType) {
		this.resourceType = resourceType;
		if(resourceType != null){
			putQueryParameter("ResourceType", resourceType);
		}
	}

	public Integer getMaxResults() {
		return this.maxResults;
	}

	public void setMaxResults(Integer maxResults) {
		this.maxResults = maxResults;
		if(maxResults != null){
			putQueryParameter("MaxResults", maxResults.toString());
		}
	}

	@Override
	public Class<DescribeDiagnosticMetricSetsResponse> getResponseClass() {
		return DescribeDiagnosticMetricSetsResponse.class;
	}

}

==> aliyun-java-sdk-ecs-4.24.60-sources.jar: com/aliyuncs/ecs/model/v20140526/DescribeDiagnosticMetricSetsRequest.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.aliyuncs.ecs.model.v20140526;

import com.aliyuncs.RpcAcsRequest;
import java.util.List;
import com.aliyuncs.http.MethodType;
import com.aliyuncs.ecs.Endpoint;

/**
 * @author auto create
 * @version 
 */
public class DescribeDiagnosticMetricSetsRequest extends RpcAcsRequest<DescribeDiagnosticMetricSetsResponse> {
	   

	private List<String> metricSetIdss;

	private String type;

	private String nextToken;

	private String resourceType;

	private Integer maxResults;
	public DescribeDiagnosticMetricSetsRequest() {
		super("Ecs", "2014-05-26", "DescribeDiagnosticMetricSets", "ecs");
		setMethod(MethodType.POST);
		try {
			com.aliyuncs.AcsRequest.class.getDeclaredField("productEndpointMap").set(this, Endpoint.endpointMap);
			com.aliyuncs.AcsRequest.class.getDeclaredField("productEndpointRegional").set(this, Endpoint.endpointRegionalType);
		} catch (Exception e) {}
	}

	public List<String> getMetricSetIdss() {
		return this.metricSetIdss;
	}

	public void setMetricSetIdss(List<String> metricSetIdss) {
		this.metricSetIdss = metricSetIdss;	
		if (metricSetIdss != null) {
			for (int i = 0; i < metricSetIdss.size(); i++) {
				putQueryParameter("MetricSetIds." + (i + 1) , metricSetIdss.get(i));
			}
		}	
	}

	public String getType() {
		return this.type;
	}

	public void setType(String type) {
		this.type = type;
		if(type != null){
			putQueryParameter("Type", type);
		}
	}

	public String getNextToken() {
		return this.nextToken;
	}

	public void setNextToken(String nextToken) {
		this.nextToken = nextToken;
		if(nextToken != null){
			putQueryParameter("NextToken", nextToken);
		}
	}

	public String getResourceType() {
		return this.resourceType;
	}

	public void setResourceType(String resourceType) {
		this.resourceType = resourceType;
		if(resourceType != null){
			putQueryParameter("ResourceType", resourceType);
		}
	}

	public Integer getMaxResults() {
		return this.maxResults;
	}

	public void setMaxResults(Integer maxResults) {
		this.maxResults = maxResults;
		if(maxResults != null){
			putQueryParameter("MaxResults", maxResults.toString());
		}
	}

	@Override
	public Class<DescribeDiagnosticMetricSetsResponse> getResponseClass() {
		return DescribeDiagnosticMetricSetsResponse.class;
	}

}
